@@ -666,6 +666,73 @@ def porcentajeerror(a,b,c,d,e,f):
         tabla=pd.concat([tabla, tablaux],ignore_index=True);
     return tabla
 
+# ElasticNet para uno
+
+def ELasticNet(Xlrinter_train, Xlrinter_test,yrlinter_train,yrlinter_test,CV):
+    ENet_models = {}
+    training_scores = []
+    test_scores = []
+    L1_ratio=[0,0.1,0.2,0.3,0.4,0.5,0.6,0.7,0.8,0.9,1]
+    for l1_ratio in L1_ratio:
+        ENet = ElasticNet(alpha=1,l1_ratio=l1_ratio,max_iter=8000).fit(Xlrinter_train, yrlinter_train)
+        training_scores.append(ENet.score(Xlrinter_train, yrlinter_train))
+        test_scores.append(ENet.score(Xlrinter_test, yrlinter_test))
+        ENet_models[l1_ratio] = ENet
+    a_aux,a=0,0
+    for k in range(0,len(L1_ratio)):
+        if test_scores[k]>test_scores[a_aux]:
+            a_aux=k
+            a=L1_ratio[k]
+    ENet=ENet_models[a]
+    score21 = cross_val_score(ENet, Xlrinter_train, np.ravel(yrlinter_train), cv=CV)
+    ENet.fit(Xlrinter_train, yrlinter_train)
+    score22 = cross_val_score(ENet, Xlrinter_test, np.ravel(yrlinter_test), cv=CV, scoring='r2')
+    y_pred23 = cross_val_predict(ENet, Xlrinter_test, np.ravel(yrlinter_test), cv=CV)
+
+    return ENet,y_pred23
+
+# Para elegir 
+def ELasticNetEleccion(df2,df3,cve):
+    c1=0
+    c2=0
+    c3=0
+    for i in range(0,5):
+        Xtodos_train, Xtodos_test, ytodos_train, ytodos_test=Entrenamiento(1,df2,df3,0.2)
+        Xrl10_train, Xrl10_test, yrl10_train, yrl10_test=Entrenamiento(10,df2,df3,0.2)
+        Xrl5_train, Xrl5_test, yrl5_train, yrl5_test=Entrenamiento(5,df2,df3,0.2)
+        Xtodos_train, Xtodos_test, Xrl10_train, Xrl10_test, Xrl5_train, Xrl5_test=Escalas(cve, Xtodos_train, Xtodos_test, 
+                                                                                          Xrl10_train, Xrl10_test, Xrl5_train, 
+                                                                                          Xrl5_test,df2)
+        ENet1,y_pred23=ELasticNet(Xtodos_train,Xtodos_test,ytodos_train,ytodos_test,10)
+        ENet2,y_pred26=ELasticNet(Xrl10_train,Xrl10_test, yrl10_train,yrl10_test,10)
+        ENet3,y_pred29=ELasticNet(Xrl5_train,Xrl5_test, yrl5_train,yrl5_test,10)
+        
+        E=porcentajeerror(ytodos_test,y_pred23,yrl10_test,y_pred26,yrl5_test,y_pred29)
+        a=E["Cantidad_Est_Relativa"][0]
+        b=E["Cantidad_Index_10_Relativa"][0]
+        c=E["Cantidad_Index_5_Relativa"][0]
+        maxi=max(a,b,c)
+        if maxi==a:
+            c1=c1+1
+        if maxi==b:
+            c2=c2+1
+        if maxi==c:
+            c3=c3+1 
+    p=max(c1,c2,c3)
+    
+    if p==c2:
+        print("El método de ElasticNet  escogido será con indexación 10. Se procederá a guardarlo")
+        joblib.dump(ENet2,"ElasticNet2_"+str(cve)+".joblib")
+        return yrl10_test,y_pred26,ENet2
+    elif p==c3:
+        print("El método de ElasticNet escogido será con indexación 5. Se procederá a guardarlo")
+        joblib.dump(ENet3,"ElasticNet3_"+str(cve)+".joblib")
+        return yrl5_test,y_pred29,ENet3    
+    elif p==c1:
+        print("El método de ElasticNet escogido será sin indexación. Se procederá a guardarlo")
+        joblib.dump(ENet1,"ElasticNet1_"+str(cve)+".joblib")
+        return ytodos_test,y_pred23,ENet1
+
 ## Random Forest para un par de datos
 def RForest(Xtrain,Xtest,ytrain,ytest,k):
     rforest1 = RandomForestRegressor(n_estimators = 600,max_features=5,random_state = 50)
